==> slush-h5bp-0.1.0.tgz: package/README.md <==
# slush-h5bp [![Build Status](https://secure.travis-ci.org/arvindr21/slush-h5bp.png?branch=master)](https://travis-ci.org/arvindr21/slush-h5bp) [![NPM version](https://badge-me.herokuapp.com/api/npm/slush-h5bp.png)](http://badges.enytc.com/for/npm/slush-h5bp) [![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/arvindr21/slush-h5bp/trend.png)](https://bitdeli.com/free "Bitdeli Badge")

> A professional front-end template for building fast, robust, and adaptable web apps or sites.


## Getting Started

### Installation

Install `slush-h5bp` globally:

```bash
$ npm install -g slush-h5bp
```

Remember to install `slush` globally as well, if you haven't already:

```bash
$ npm install -g slush
```

### Usage

Create a new folder for your project:

```bash
$ mkdir my-slush-h5bp
```

Run the generator from within the new folder:

```bash
$ cd my-slush-h5bp && slush h5bp
```

## Getting To Know Slush

Slush is a tool that uses Gulp for project scaffolding.

Slush does not contain anything "out of the box", except the ability to locate installed slush generators and to run them with liftoff.

To find out more about Slush, check out the [documentation](https://github.com/klei/slush).

## Contributing

See the [CONTRIBUTING Guidelines](https://github.com/arvindr21/slush-h5bp/blob/master/CONTRIBUTING.md)

## Support
If you have any problem or suggestion please open an issue [here](https://github.com/arvindr21/slush-h5bp/issues).

## License 

The MIT License

Copyright (c) 2014, Arvind Ravulavaru

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

==> slush-h5bp-0.1.4.tgz: package/README.md <==
# slush-h5bp [![Build Status](https://secure.travis-ci.org/arvindr21/slush-h5bp.png?branch=master)](https://travis-ci.org/arvindr21/slush-h5bp) [![NPM version](https://badge-me.herokuapp.com/api/npm/slush-h5bp.png)](http://badges.enytc.com/for/npm/slush-h5bp) [![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/arvindr21/slush-h5bp/trend.png)](https://bitdeli.com/free "Bitdeli Badge")

[![NPM](https://nodei.co/npm/slush-h5bp.png?downloads=true&stars=true)](https://nodei.co/npm/slush-h5bp/)

> A professional front-end template for building fast, robust, and adaptable web apps or sites.

## Getting Started

### Installation

Install `slush-h5bp` globally:

```bash
$ npm install -g slush-h5bp
```

Remember to install `slush` globally as well, if you haven't already:

```bash
$ npm install -g slush
```

### Usage

Create a new folder for your project:

```bash
$ mkdir my-h5bp-app
```

Run the generator from within the new folder:

```bash
$ cd my-h5bp-app && slush h5bp
```

To run the HTML5 Boilerplate application 

```bash
$ gulp
```
And then navigate to http://localhost:1881


## Getting To Know Slush

Slush is a tool that uses Gulp for project scaffolding.

Slush does not contain anything "out of the box", except the ability to locate installed slush generators and to run them with liftoff.

To find out more about Slush, check out the [documentation](https://github.com/klei/slush).

## Contributing

See the [CONTRIBUTING Guidelines](https://github.com/arvindr21/slush-h5bp/blob/master/CONTRIBUTING.md)

## Support
If you have any problem or suggestion please open an issue [here](https://github.com/arvindr21/slush-h5bp/issues).

## License 

The MIT License

Copyright (c) 2014, Arvind Ravulavaru

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.
